Learn R Programming

MCID (version 0.1.0)

g.ifun: The square of the score function for determining the individualized MCID

Description

The square of the score function for determining the individualized MCID

Usage

g.ifun(z_tilde, val, ind1, ind2, w)

Arguments