Learn R Programming

MCID (version 0.1.0)

pmcid.ramp.smooth: The value function needed to be optimized for determining the population MCID

Description

The value function needed to be optimized for determining the population MCID

Usage

pmcid.ramp.smooth(x, y, w, n, tau, t, delta)

Arguments